<?php 
/**
 * Piwik - Open source web analytics
 * 
 * @link http://piwik.org
 * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
 * @version $Id: en.php 6848 2012-08-20 23:18:38Z capedfuzz $
 * 
 * @category Piwik_Plugins
 * @package Piwik_ExamplePlugin
 */

$translations = array(
	'ExamplePlugin_PluginDescription' => 'Example Plugin: This plugin shows how to create a very simple plugin, that exports two widgets in the Dashboard.',
	'ExamplePlugin_exampleWidgets' => 'Example Widgets',
	'ExamplePlugin_exampleWidget' => 'Example Widget',
	'ExamplePlugin_photostreamMatt' => 'Matt\'s Photos',
	'ExamplePlugin_piwikForumVisits' => 'Piwik Forums visits',
	'ExamplePlugin_PiwikForumReceivedVisits' => 'On %s, Piwik forums received %s visits.'
	
);
